@@ -13,13 +13,20 @@ our $DEBUG = 0;
 
 =head1 NAME
 
-eBay::API::Simple::Finding
+eBay::API::Simple::Finding - Support for eBay's Finding 2.0 web service
 
-=head1 SYNPOSIS
+=head1 DESCRIPTION
+
+This class provides support for eBay's Finding 2.0 web services.
+
+See http://developer.ebay.com/products/finding/
+
+=head1 USAGE
 
   my $call = eBay::API::Simple::Finding->new( 
     { appid => '<your app id here>' } 
   );
+  
   $call->execute( 'findItemsByKeywords', { keywords => 'shoe' } );
 
   if ( $call->has_error() ) {
@@ -40,25 +47,60 @@ eBay::API::Simple::Finding
   foreach my $n ( @nodes ) {
     print $n->findvalue('title/text()') . "\n";
   }
-  
-=head1 new 
 
-Constructor for the Shopping API call
+=head1 PUBLIC METHODS
 
-  my $call = eBay::API::Simple::Finding->new( 
-    { appid => '<your app id here>' } 
-  );
- 
-  my $call = eBay::API::Simple::Finding->new( {
-    siteid  => 'EBAY-US',       # custom site id 
-    domain  => 'svcs.ebay.com', # custom domain
-    uri     => '/services/search/FindingService/v1',  # custom uri 
-    appid   => '<your appid>',    # custom appid
-    version => '1.0.0',      # custom version
-    https   => 0,            # 0 or 1
+=head2 new( { %options } } 
+
+Constructor for the Finding API call
+
+  my $call = eBay::API::Simple::Finding->new( { 
+    appid => '<your app id here>' 
+    ... 
   } );
-    
-=head2 ebay.ini
+
+=head3 Options
+
+=over 4
+
+=item appid (required)
+
+This appid is required by the web service. App ids can be obtained at 
+http://developer.ebay.com
+
+=item siteid
+
+eBay site id to be supplied to the web service endpoint
+
+defaults to EBAY-US
+
+=item domain
+
+domain for the web service endpoint
+
+defaults to svcs.ebay.com
+
+=item uri
+
+endpoint URI
+
+defaults to /services/search/FindingService/v1
+
+=item version
+
+Version to be supplied to the web service endpoint
+
+defaults to 1.0.0
+
+=item https
+
+Specifies is the API calls should be made over https.
+
+defaults to 0
+
+=back
+
+=head3 ALTERNATE CONFIG VIA ebay.ini
 
 The constructor will fallback to the ebay.ini file to get any missing 
 credentials. The following files will be checked, ./ebay.ini, ~/ebay.ini, 
@@ -86,53 +128,20 @@ sub new {
     return $self;    
 }
 
-=head1 _get_request_body
+=head2 execute( $verb, $call_data )
 
-This method supplies the request body for the Shopping API call
-
-=cut
-
-sub _get_request_body {
-    my $self = shift;
-
-    my $xml = "<?xml version='1.0' encoding='utf-8'?>"
-        . "<" . $self->{verb} . "Request xmlns=\"http://www.ebay.com/marketplace/search/v1/services\">"
-        . XMLout( $self->{call_data}, NoAttr => 1, KeepRoot => 1, RootName => undef )
-        . "</" . $self->{verb} . "Request>";
-
-    return $xml; 
-}
-
-=head1 _get_request_headers 
-
-This method supplies the headers for the Shopping API call
-
-=cut
-
-sub _get_request_headers {
-    my $self = shift;
-   
-    my $obj = HTTP::Headers->new();
-
-    $obj->push_header("X-EBAY-SOA-SERVICE-VERSION" => $self->api_config->{version});
-    $obj->push_header("X-EBAY-SOA-SECURITY-APPNAME"  => $self->api_config->{appid});
-    $obj->push_header("X-EBAY-SOA-GLOBAL-ID"  => $self->api_config->{siteid});
-    $obj->push_header("X-EBAY-SOA-OPERATION-NAME" => $self->{verb});
-    $obj->push_header("X-EBAY-SOA-REQUEST-DATA-FORMAT"  => $self->api_config->{request_encoding});
-    $obj->push_header("X-EBAY-SOA-RESPONSE-DATA-FORMAT" => $self->api_config->{response_encoding});
-    $obj->push_header("Content-Type" => "text/xml");
-    
-    return $obj;
-}
-
-=head1 execute( $verb, $call_data )
+  $self->execute( 'findItemsByKeywords', { keywords => 'shoe' } );
  
-Calling this method will make build and execute the api request.
-  
-  $verb      = call verb, i.e. FindItems 
-  $call_data = hashref of call_data that will be turned into xml.
+This method will construct the API request based on the $verb and
+the $call_data and then post the request to the web service endpoint. 
 
-  $call->execute( 'findItemsByKeywords', { keywords => 'shoe' } );
+=item $verb (required)
+
+call verb, i.e. findItemsItemsByKeywords
+
+=item $call_data (required)
+
+hashref of call_data that will be turned into xml.
 
 =cut
 
@@ -160,9 +169,98 @@ sub execute {
     }
 
 }
-=head1 _get_request_object 
 
-This method creates the request object and returns to the parent class
+=head1 BASECLASS METHODS
+
+=head2 request_agent
+
+Accessor for the LWP::UserAgent request agent
+
+=head2 request_object
+
+Accessor for the HTTP::Request request object
+
+=head2 request_content
+
+Accessor for the complete request body from the HTTP::Request object
+
+=head2 response_content
+
+Accessor for the HTTP response body content
+
+=head2 response_object
+
+Accessor for the HTTP::Request response object
+
+=head2 response_dom
+
+Accessor for the LibXML response DOM
+
+=head2 response_hash
+
+Accessor for the hashified response content
+
+=head2 nodeContent( $tag, [ $dom ] ) 
+
+Helper for LibXML that retrieves node content
+
+=head2 errors 
+
+Accessor to the hashref of errors
+
+=head2 has_error
+
+Returns true if the call contains errors
+
+=head2 errors_as_string
+
+Returns a string of API errors if there are any.
+
+=head1 PRIVATE METHODS
+
+=head2 _get_request_body
+
+This method supplies the XML body for the web service request
+
+=cut
+
+sub _get_request_body {
+    my $self = shift;
+
+    my $xml = "<?xml version='1.0' encoding='utf-8'?>"
+        . "<" . $self->{verb} . "Request xmlns=\"http://www.ebay.com/marketplace/search/v1/services\">"
+        . XMLout( $self->{call_data}, NoAttr => 1, KeepRoot => 1, RootName => undef )
+        . "</" . $self->{verb} . "Request>";
+
+    return $xml; 
+}
+
+=head2 _get_request_headers 
+
+This method supplies the HTTP::Headers obj for the web service request
+
+=cut
+
+sub _get_request_headers {
+    my $self = shift;
+   
+    my $obj = HTTP::Headers->new();
+
+    $obj->push_header("X-EBAY-SOA-SERVICE-VERSION" => $self->api_config->{version});
+    $obj->push_header("X-EBAY-SOA-SECURITY-APPNAME"  => $self->api_config->{appid});
+    $obj->push_header("X-EBAY-SOA-GLOBAL-ID"  => $self->api_config->{siteid});
+    $obj->push_header("X-EBAY-SOA-OPERATION-NAME" => $self->{verb});
+    $obj->push_header("X-EBAY-SOA-REQUEST-DATA-FORMAT"  => $self->api_config->{request_encoding});
+    $obj->push_header("X-EBAY-SOA-RESPONSE-DATA-FORMAT" => $self->api_config->{response_encoding});
+    $obj->push_header("Content-Type" => "text/xml");
+    
+    return $obj;
+}
+
+=head2 _get_request_object 
+
+This method creates and returns the HTTP::Request object for the
+web service call.
 
 =cut
 
